@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011 Philipp Spitzer, gregor herrmann
+ * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -28,18 +28,18 @@ class ConflictDialogContainer: public TabContainer
     Q_OBJECT
 public:
     ConflictDialogContainer(QWidget *aParent);
-    virtual ~ConflictDialogContainer(){}
+    virtual ~ConflictDialogContainer() {}
 
-    void setEventId(int aEventId) { mEventId = aEventId; }
+public slots:
+    void setEventId(int aEventId, int conferenceId);
+    void loadEvents(); // update the conflicts
 
 protected:
-    virtual void loadEvents( const QDate &aDate, const int aConferenceId );
-
-protected slots:
-    virtual void updateTreeView(const QDate &aDate);
+    virtual void loadEvents(const QDate &aDate, const int aConferenceId); // the date and conference are ignored
 
 private:
     int mEventId;
+    int mConferenceId;
 };
 
 #endif /* CONFLICTDIALOGCONTAINER_H */
