@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011 Philipp Spitzer, gregor herrmann
+ * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -19,23 +19,19 @@
  */
 #include "conflictsdialog.h"
 
-ConflictsDialog::ConflictsDialog(int aEventId, QWidget *aParent)
+ConflictsDialog::ConflictsDialog(int aEventId, int aConferenceId, QWidget *aParent)
     : QDialog(aParent)
 {
     setupUi(this);
-    connect(container, SIGNAL(eventHasChanged(int,bool)), this, SIGNAL(eventHasChanged(int,bool)));
-    connect(container, SIGNAL(eventHasChanged(int,bool)), container, SLOT(updateTreeViewModel(int,bool)));
+    connect(container, SIGNAL(eventChanged(int,bool)), this, SIGNAL(eventChanged(int,bool)));
+    connect(container, SIGNAL(eventChanged(int,bool)), container, SLOT(loadEvents()));
 
-    container->setEventId(aEventId);
-
-    int confId = Conference::activeConference();
-    QDate startDate = Conference::getById(confId).start();
-    QDate endDate = Conference::getById(confId).end();
-    container->setDates(startDate, endDate);
+    container->setEventId(aEventId, aConferenceId);
 }
 
+
 ConflictsDialog::~ConflictsDialog()
 {
-    disconnect(container, SIGNAL(eventHasChanged(int,bool)), this, SIGNAL(eventHasChanged(int,bool)));
+    disconnect(container, SIGNAL(eventChanged(int,bool)), this, SIGNAL(eventChanged(int,bool)));
 }
 
