@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011 Philipp Spitzer, gregor herrmann
+ * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -27,10 +27,10 @@ class ConflictsDialog : public QDialog, Ui::ConflictsDialog
 {
     Q_OBJECT
 public:
-    ConflictsDialog(int aEventId, QWidget *aParent = NULL);
+    ConflictsDialog(int aEventId, int aConferenceId, QWidget *aParent = NULL);
     ~ConflictsDialog();
 signals:
-    void eventHasChanged(int aEventId, bool aReloadModel = false);
+    void eventChanged(int aEventId, bool favouriteChanged);
 };
 
 #endif /* CONFLICTSDIALOG_H */ 
