@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011 Philipp Spitzer, gregor herrmann
+ * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -27,7 +27,11 @@ class DayViewTabContainer: public TabContainer {
     Q_OBJECT
 public:
     DayViewTabContainer(QWidget *aParent);
-    virtual ~DayViewTabContainer();
+    virtual ~DayViewTabContainer() {}
+
+public slots:
+    void expandTimeGroup(QTime time, int conferenceId);
+
 protected:
     virtual void loadEvents(const QDate &aDate, const int aConferenceId );
 };
