@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011 Philipp Spitzer, gregor herrmann
+ * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -18,12 +18,12 @@
  * ConfClerk.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "eventdialog.h"
-#include <conference.h>
+#include "conference.h"
 
 #include <QScrollBar>
 
 #ifdef MAEMO
-#include <alarm.h>
+#include "alarm.h"
 #endif
 
 EventDialog::EventDialog(const int &aEventId, QWidget *aParent)
@@ -54,12 +54,12 @@ EventDialog::EventDialog(const int &aEventId, QWidget *aParent)
 
     if(event.isFavourite())
     {
-        favouriteButton->setIcon(QIcon(":/icons/emblem-new.png"));
+        favouriteButton->setIcon(QIcon(":/icons/favourite-on.png"));
     }
 
     if(event.hasAlarm())
     {
-        alarmButton->setIcon(QIcon(":/icons/appointment-soon.png"));
+        alarmButton->setIcon(QIcon(":/icons/alarm-on.png"));
     }
 }
 
@@ -71,12 +71,12 @@ void EventDialog::favouriteClicked()
     if(event.isFavourite())
     {
         event.setFavourite(false);
-        favouriteButton->setIcon(QIcon(":/icons/emblem-new-off.png"));
+        favouriteButton->setIcon(QIcon(":/icons/favourite-off.png"));
     }
     else
     {
         event.setFavourite(true);
-        favouriteButton->setIcon(QIcon(":/icons/emblem-new.png"));
+        favouriteButton->setIcon(QIcon(":/icons/favourite-on.png"));
     }
     event.update("favourite");
 
@@ -86,13 +86,13 @@ void EventDialog::favouriteClicked()
         conflicts = Event::conflictEvents(event.id(),Conference::activeConference());
     }
 
-    // have to emit 'eventHasChanged' signal on all events in conflict
+    // have to emit 'eventChanged' signal on all events in conflict
     for(int i=0; i<conflicts.count(); i++)
-        emit(eventHasChanged(conflicts[i].id()));
+        emit eventChanged(conflicts[i].id(), false);
 
     // since the Favourite icon has changed, update TreeViews accordingly
     // all TreeViews have to listen on this signal
-    emit(eventHasChanged(event.id(),true));
+    emit eventChanged(event.id(), true);
 }
 
 void EventDialog::alarmClicked()
@@ -102,27 +102,27 @@ void EventDialog::alarmClicked()
     if(event.hasAlarm())
     {
         event.setHasAlarm(false); // update DB
-        alarmButton->setIcon(QIcon(":/icons/appointment-soon-off.png"));
+        alarmButton->setIcon(QIcon(":/icons/alarm-off.png"));
 #ifdef MAEMO
         // remove alarm from the 'alarmd' alrms list
         Alarm alarm;
-        alarm.deleteAlarm(event.id());
+        alarm.deleteAlarm(event.conferenceId(), event.id());
         // TODO: test if removing was successfull
 #endif /* MAEMO */
     }
     else
     {
         event.setHasAlarm(true);
-        alarmButton->setIcon(QIcon(":/icons/appointment-soon.png"));
+        alarmButton->setIcon(QIcon(":/icons/alarm-on.png"));
 #ifdef MAEMO
         // add alarm to the 'alarmd'
         Alarm alarm;
-        int cookie = alarm.addAlarm(event.id(),event.title(),QDateTime::currentDateTime().addSecs(10));
+        alarm.addAlarm(event.conferenceId(), event.id(), event.title(), event.start().addSecs(PRE_EVENT_ALARM_SEC));
 #endif /* MAEMO */
     }
     event.update("alarm");
     // since the Alarm icon has changed, update TreeView accordingly
     // all TreeViews have to listen on this signal
-    emit(eventHasChanged(event.id()));
+    emit eventChanged(event.id(), false);
 }
 
