@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011 Philipp Spitzer, gregor herrmann
+ * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -41,11 +41,18 @@ public:
 signals:
     void conferenceRemoved();
 private slots:
-    void aboutApp();
-    void eventHasChanged(int aEventId, bool aReloadModel);
-    void setup();
+    void on_conferencesAction_triggered();
+    void on_settingsAction_triggered();
+    void on_aboutAction_triggered();
+    void on_reloadAction_triggered();
+    void on_nowAction_triggered();
+    void on_searchAction_triggered();
+    void on_expandAllAction_triggered();
+    void on_collapseAllAction_triggered();
+
+    void onEventChanged(int aEventId, bool favouriteChanged);
+    void onSearchResultChanged();
     // TODO: remove
-    void showConferences();
     void networkQueryFinished(QNetworkReply*);
     void importFromNetwork(const QString&);
     void importFromFile(const QString&);
