@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011 Philipp Spitzer, gregor herrmann
+ * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -21,7 +21,7 @@
 #ifndef SEARCHTAB_H_
 #define SEARCHTAB_H_
 
-#include <QWidget>
+#include <QtGui>
 
 #include "tabcontainer.h"
 #include "searchhead.h"
@@ -30,11 +30,19 @@ class SearchTabContainer: public TabContainer {
     Q_OBJECT
 public:
     SearchTabContainer(QWidget *aParent);
-    virtual ~SearchTabContainer();
+    virtual ~SearchTabContainer() {}
+    bool searchDialogIsVisible() const;
+    int searchResultCount(const QDate& date) const; ///< returns the number of events found on that specific date
+
 protected:
     virtual void loadEvents( const QDate &aDate, const int aConferenceId );
+
+signals:
+    void searchResultChanged();
+
 public slots:
-    void searchAgainClicked(); // made it public - to show header when 1.st conf importing is done successfuly
+    void showSearchDialog(bool show=true);
+
 private slots:
     void searchButtonClicked();
 
