@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011 Philipp Spitzer, gregor herrmann
+ * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -41,11 +41,11 @@ protected:
     virtual void loadEvents( const QDate &aDate, const int aConferenceId ) = 0;
 
 signals:
-    void eventHasChanged(int aEventId, bool aReloadModel);
+    void eventChanged(int aEventId, bool aReloadModel);
 
 public slots:
-    virtual void updateTreeViewModel(int aEventId, bool aReloadModel = false);
-    void setDates(const QDate &aStart, const QDate &aEnd);
+    virtual void redisplayEvent(int aEventId);
+    void redisplayDate(const QDate& curDate);
 
 protected slots:
     virtual void updateTreeView(const QDate &aDate);
