@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011 Philipp Spitzer, gregor herrmann
+ * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -48,25 +48,25 @@ void EventModel::createTimeGroups()
     mParents.clear();
     if (mEvents.empty()) return;
 
-    const int minTimeSpan = 3600; // one hour
-    const int minChildCount = 3; // minimum number of events in one group
+    const int minTimeSpan = 3600; // one hour // minimum duration of a group in seconds
+    const int minChildCount = 3;  // minimum number of events in one group
 
-    // Create the first time group. The events have to be sorted by start time at this point!
-    QTime groupStartTime(mEvents.first().start().time().hour(), 0);
-    QTime groupEndTime = groupStartTime.addSecs(mEvents.first().duration());
+    QDateTime groupStartDateTime(mEvents.first().start().date(), QTime(mEvents.first().start().time().hour(), 0), mEvents.first().start().timeSpec());
+    QDateTime groupEndDateTime = groupStartDateTime.addSecs(mEvents.first().duration());
     mGroups << EventModel::Group("", 0);
     int timeSpan = minTimeSpan;
 
     for (int i = 0; i != mEvents.count(); ++i) {
-        QTime eventStartTime = mEvents.at(i).start().time();
-        QTime eventEndTime = eventStartTime.addSecs(mEvents.at(i).duration());
+        QDateTime eventStartDateTime = mEvents.at(i).start();
+        QDateTime eventEndDateTime = eventStartDateTime.addSecs(mEvents.at(i).duration());
 
-        if (eventStartTime >= groupStartTime.addSecs(timeSpan)) {
+        if (eventStartDateTime >= groupStartDateTime.addSecs(timeSpan)) {
             // a new group could be necessary
             if (mGroups.last().mChildCount < minChildCount) {
                 // too few events in the group => no new group
                 // except a gap in time would occur that is longer than minTimeSpan
-                if (i > 0 && qMax(mEvents.at(i-1).start().time().addSecs(mEvents.at(i-1).duration()), groupEndTime).secsTo(eventStartTime) < minTimeSpan) {
+                QDateTime prevEventStartDateTime = mEvents.at(i).start();
+                if (i > 0 && qMax(prevEventStartDateTime.addSecs(mEvents.at(i-1).duration()), groupEndDateTime).secsTo(eventStartDateTime) < minTimeSpan) {
                     timeSpan += minTimeSpan;
                     --i;
                     continue; // repeat with the same event
@@ -75,8 +75,8 @@ void EventModel::createTimeGroups()
 
             // a new group is necessary
             mGroups.last().setTitle(mEvents);
-            groupStartTime = groupStartTime.addSecs(timeSpan);
-            groupEndTime = groupStartTime.addSecs(mEvents.at(i).duration());
+            groupStartDateTime = groupStartDateTime.addSecs(timeSpan);
+            groupEndDateTime = groupStartDateTime.addSecs(mEvents.at(i).duration());
             mGroups << EventModel::Group("", i);
             timeSpan = minTimeSpan;
         }
@@ -84,7 +84,7 @@ void EventModel::createTimeGroups()
         // insert event into current group
         mParents[mEvents.at(i).id()] = mGroups.count() - 1;
         mGroups.last().mChildCount += 1;
-        groupEndTime = qMax(eventEndTime, groupEndTime);
+        groupEndDateTime = qMax(eventEndDateTime, groupEndDateTime);
     }
 
     // the last group needs a title as well
@@ -241,7 +241,7 @@ void EventModel::loadEvents(const QDate &aDate, int aConferenceId)
     // check for existence of the conference in the DB
     if(Conference::getAll().count())
     {
-        mEvents = Event::getByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId, "start");
+        mEvents = Event::getByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId, "start, duration");
     }
     createTimeGroups();
 }
@@ -264,7 +264,7 @@ int EventModel::loadSearchResultEvents(const QDate &aDate, int aConferenceId)
     if(Conference::getAll().count())
     {
         try{
-            mEvents = Event::getSearchResultByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId, "start");
+            mEvents = Event::getSearchResultByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId, "start, duration");
         }
         catch( OrmException &e  ){
             qDebug() << "Event::getSearchResultByDate failed: " << e.text();
@@ -285,7 +285,7 @@ void EventModel::loadEventsByTrack(const QDate &aDate, int aConferenceId)
     clearModel();
     if (Conference::getAll().count())
     {
-        mEvents = Event::getByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId, "xid_track, start");
+        mEvents = Event::getByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId, "xid_track, start, duration");
     }
     createTrackGroups();
 }
@@ -300,19 +300,8 @@ void EventModel::loadEventsByRoom(const QDate &aDate, int aConferenceId)
     createRoomGroups();
 }
 
-void EventModel::loadNowEvents(int aConferenceId)
-{
-    clearModel();
-    // check for existence of the conference in the DB
-    if(Conference::getAll().count())
-    {
-        mEvents = Event::nowEvents(aConferenceId, "start");
-    }
-    createTimeGroups();
-}
 
-void EventModel::loadConflictEvents(int aEventId, int aConferenceId)
-{
+void EventModel::loadConflictEvents(int aEventId, int aConferenceId) {
     clearModel();
     // check for existence of the conference in the DB
     if(Conference::getAll().count())
