@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011 Philipp Spitzer, gregor herrmann
+ * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -36,8 +36,10 @@ void ScheduleXmlParser::parseData(const QByteArray &aData, const QString& url)
 {
     QDomDocument document;
     QString xml_error;
-    if (!document.setContent (aData, false, &xml_error)) {
-        error_message("Could not parse schedule: " + xml_error);
+    int xml_error_line;
+    int xml_error_column;
+    if (!document.setContent (aData, false, &xml_error, &xml_error_line, &xml_error_column)) {
+        error_message("Could not parse schedule: " + xml_error + " at line " + QString("%1").arg(xml_error_line) + " column " + QString("%1").arg(xml_error_column));
         return;
     }
 
